<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml\Form\MiniorangeIDPSetup.
 */

namespace Drupal\miniorange_saml\Form;

use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml\Utilities;
use Drupal\miniorange_saml\mo_saml_visualTour;


class MiniorangeIDPSetup extends FormBase {

    public function getFormId() {
        return 'miniorange_saml_idp_setup';
    }

    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {

        global $base_url;
        $url = \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_base_url');
        $issuer = \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_entity_id');
        $module_path = drupal_get_path('module', 'miniorange_saml');
        $b_url = isset($url) && !empty($url)? $url:$base_url;
        $issuer_id = isset($issuer) && !empty($issuer)? $issuer:$base_url;

        Utilities::visual_tour_start($form, $form_state);

        $acs_url = $b_url . '/samlassertion';

        $form['header_top_style_1'] = array(
            '#markup' => '<div class="mo_saml_table_layout_1">',
        );

        $form['markup_top'] = array(
            '#markup' => '<div class="mo_saml_table_layout mo_saml_container">'
        );
        $form['miniorange_saml_tour_button'] = array(
            '#attached' => array(
                'library' => array(
                    'miniorange_saml/miniorange_saml.Vtour',
                    'miniorange_saml/miniorange_saml_copy.icon',
                )
            ),
            '#markup' => '<div><h2>Service Provider Metadata &nbsp; <a id="Restart_moTour" class="btn btn-danger btn-sm" onclick="Restart_moTour()">Take a Tour</a></h2><hr></div><br>',
        );

        $form['mo_saml_metadata_option'] = array(
            '#markup' => '<br><div class="mo_text_color"><b>Provide this plugin information to your Identity Provider team. You can choose any one of the below options:</b></div>',
        );

        $form['markup_1_idp_sp_1'] = array(
            '#markup' => '<br><b>a) Provide this metadata URL to your Identity Provider:</b><br>',
        );

        $form['markup_idp_sp_2'] = array(
            '#markup' => '<div>
                            <div class="mo_saml_highlight_background_url_note" id="idp_metadata_url">
                                <code><b>
                                    <span>
                                        <a target="_blank" href="' . $b_url . '/modules/miniorange_saml/includes/metadata/metadata.php">' . $b_url . '/modules/miniorange_saml/includes/metadata/metadata.php' . '</a>
                                    </span></b>
                                </code>
                            </div>
                            <img class ="fa fa-fw fa-lg fa-copy mo_copy mo-margin" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">
                        </div>',
        );

        $form['mo_saml_download_btn_title'] = array(
            '#markup' => '<br><br><div><b>b) Download the Plugin XML metadata and upload it on your Identity Provider : </b>
                        <span><a href="' . $b_url . '/modules/miniorange_saml/includes/metadata/metadata.php?download=true" class="btn btn-danger btn-sm">Download XML Metadata</a></span></div>',
        );

        $form['header'] = array(
            '#markup' => '<br><br><div><b>c) Provide the following information to your Identity Provider. Copy it and keep it handy.</b></div><br>',
        );

        $form['mo_saml_attrs_list_idp'] = array(
            '#markup' => '<div class="table-responsive" style="font-family: sans-serif;font-size: 12px;" id="mo_idp_vt_conf_table">   
                <table class="mo_guide_table mo_guide_table-striped mo_copy_icon_not_center" style="border: 1px solid #ddd;max-width: 100%;border-collapse: collapse;">
                    <thead>
                        <tr>
                            <th class="mo_guide_text-center mo_td_values">ATTRIBUTE</th>
                            <th class="mo_guide_text-center mo_td_values">VALUE</th>   
                            <tbody style="font-size: 12px;color:gray;">     
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">SP Entity ID/Issuer</td>
                                    <td>						               
						               <span id="issuer_id">' . $issuer_id . '</span>						                 
                                       <img class ="fa fa-fw fa-pull-right fa-lg fa-copy mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>                                
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">SP ACS URL</td>
                                    <td>						               
						               <span id="login_url">' . $acs_url . '</span>						                 
                                       <img class ="fa fa-fw fa-pull-right fa-lg fa-copy mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Audience URI</td>
                                    <td>						               
						               <span id="audience_url">' . $b_url . '</span>						                 
                                       <img class ="fa fa-fw fa-pull-right fa-lg fa-copy mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Recipient URL</td>
                                    <td>						               
						               <span id="recipientURL">' . $acs_url . '</span>						                 
                                       <img class ="fa fa-fw fa-pull-right fa-lg fa-copy mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Destination URL</td>
                                    <td>						               
						               <span id="destinationURL">' . $acs_url . '</span>						                 
                                       <img class ="fa fa-fw fa-pull-right fa-lg fa-copy mo_copy" src="'. $base_url.'/'.$module_path . '/includes/images/copy-regular.svg">			
						            </td>                                    
                                </tr>
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">Single Logout URL</td>
                                    <td>						               
						               Available in </b><a href="' . $base_url . '/admin/config/people/miniorange_saml/licensing">Premium, Enterprise</a> version.		
						            </td>                                    
                                </tr>  
                                <tr>
                                    <td style="font-weight:bold;padding: 15px;">NameID Format</td>
                                    <td>						               
						               urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress		
						            </td>                                    
                                </tr>                                                                                                                                                                                                                  
                            </tbody>                                                 
                        </tr>
                    </thead>
                    </table>
          </div></div>'
        );

        Utilities::spConfigGuide($form, $form_state);


        $form['miniorange_idp_guide_link_end'] = array(
            '#markup' => '</div>',
        );

        Utilities::AddSupportButton($form, $form_state);

        return $form;

    }

    function saved_support($form, &$form_state)
    {
        $email = $form['miniorange_saml_email_address_support']['#value'];
        $phone = $form['miniorange_saml_phone_number_support']['#value'];
        $query = $form['miniorange_saml_support_query_support']['#value'];
        Utilities::send_support_query($email, $phone, $query);
    }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

    }
}